ComponentEntry

Struct ComponentEntry 

pub struct ComponentEntry {
    pub key: Identifier,
    codecs: ComponentCodecs,
    ignore_swap_animation: bool,
}
Metadata for a registered component type.

Contains the component’s key and all serialization functions needed to read/write the component for network and persistent storage.

Fields

key: Identifier

The component’s identifier (e.g., “minecraft:damage”)

codecs: ComponentCodecsignore_swap_animation: bool

Implementations

Source

impl ComponentEntry

pub(super) fn implemented( key: Identifier, expected_type_key: DowncastTypeKey, network_reader: NetworkReader, network_writer: NetworkWriter, persistent_codecs: Option<(NbtReader, NbtWriter, fn(&ComponentData) -> Result<i32>, Option<fn(&ComponentData) -> Result<()>>)>, ignore_swap_animation: bool, ) -> Self

pub fn validates(&self, data: &ComponentData) -> bool

Validates that a ComponentData value matches the concrete type for this component.

Returns true if the data is valid for this component type, false otherwise. This prevents plugins from setting wrong types on vanilla components.

pub fn read_network(&self, data: &mut Cursor<&[u8]>) -> Result<ComponentData>

Decodes this component’s network value.

pub fn write_network( &self, data: &ComponentData, writer: &mut Vec<u8>, ) -> Result<()>

Encodes this component’s network value after validating its concrete type.

pub fn read_nbt(&self, tag: BorrowedNbtTag<'_, '_>) -> Option<ComponentData>

Decodes this component’s persistent NBT value.

pub fn write_nbt(&self, data: &ComponentData) -> Result<OwnedNbtTag>

Encodes this component’s persistent NBT value after validating its concrete type.

pub fn validate_persistent_encoding( &self, data: &ComponentData, ) -> Result<OwnedNbtTag>

Checks that a value accepted by the stream codec is also accepted by the persistent codec.

pub fn compute_hash(&self, data: &ComponentData) -> Result<i32>

Computes the vanilla HashOps value through this component’s persistent codec.

pub const fn is_persistent(&self) -> bool

Returns whether vanilla defines this as a persistent component.

pub const fn ignore_swap_animation(&self) -> bool

Returns whether changes to this component are ignored for held-item swap animation.

pub fn read_nbt_owned(&self, tag: &OwnedNbtTag) -> Option<ComponentData>

Decodes an owned NBT value with this component’s registered persistent codec.