pub(super) type ComponentHash = fn(&ComponentData) -> Result<i32>;Expand description
Function for hashing a component through its persistent codec shape.
pub(super) type ComponentHash = fn(&ComponentData) -> Result<i32>;Function for hashing a component through its persistent codec shape.